/*
border #AED0EA;
inside #DEEDF7;
*/
/** Main layout */
body {
	font-family: Helvetica, Geneva, Arial, SunSans-Regular, sans-serif, Verdana, "Trebuchet MS", SunSans-Regular;
	font-size:11pt ;
}
html,
body {
   margin:0;
   padding:0;
   height:100%;
}
#menuitem_beta {
	color:#999;
	text-align: center;
	font-style:italic;
}

#page {
	min-height: 100%;
	position: relative;
	max-width: 1920px;
	margin-right: auto;
	margin-left: auto;

}
#header {
   position: fixed;
	z-index: 1000;
	min-width: 800px;
	width: 100%;
	max-width: 1920px;
}
#page_body {
	padding:10px;
	padding-top:31px;   /* Height of the header */
	padding-bottom:110px;   /* Height of the footer + 10px*/
	width: 95%;
	margin-left: auto;
	margin-right: auto;
}
/***** footer *****/
#footer {
	position: absolute;
	bottom:0;
	width:100%;
	height:100px;   /* Height of the footer. Please ensure to update padding-bottom in #page_body when changing this value */
	font-size:10px;
	background-color: white;
	clear: both;
}
#footer_content {
	margin: 0px auto;
	/*width: 620px;
	min-width: 620px;*/
	display: table;
	text-align:center;
}
#footer_text {
	margin: auto 10px;
}
#footer, #footer a {
color:#999;
}
#footer a:hover {
color:#DEEDF7;
}
#footer h3 {
color:#2c78ff;
margin:0px;
font-size:16px;
}

#footer #footer_logo {
border:0;
float:left;
padding-right: 3px;
}
#footer > span {
	float:left;
}
.footer-float-left {
	float: left;
}
#footer_content_sponsor {
	margin-left:25px;
}
#footer_content_sponsor img {
	height: 55px;
}
/***** info popups *****/
a.info:link, a.info:hover {
	cursor:text;
	color:black;
	text-decoration: none;
}
.help {
	border-radius: 10px;
	background-color: #DEEDF7;/*#AED0EA*/
	cursor: pointer;
	height: 10px;
	width: 10px;
	font-size:x-small;
	font-size: xx-small;
	vertical-align:super;
	color: white;
	display: inline-block;
	text-align:center;
	margin: 2px;
}

/* End */
.help span, a.info span{
	display: none;
	position:absolute;
	z-index:1;
	/*top:2em;*/
	left:60px;
	width:35em;
	margin-top:22px;
	border:1px solid #AED0EA;
	background-color:#DEEDF7;
	color:#2779AA;
	text-align:justify;
	font-size:15px;
	font-weight:normal;
	padding:8px 12px;
	line-height:15px;
	border-radius: 5px;

}
/***** login form ********/
#loginform > input[type="text"], #loginform > input[type="password"] {
	padding: 10px;
	height:1em;
	line-height:1em;
	width:90%;
}
.login_item {
	height: 150px;
	width: 150px;
	display: inline-block;
	background-repeat:no-repeat;
	background-position:center center;
	margin: auto 20px;
}
#login_admin {
	/*Background Images moved to login.php for subdirectory installs*/
}
#login_ari {
	/*Background Images moved to login.php for subdirectory installs*/
}
#login_fop {
	/*Background Images moved to login.php for subdirectory installs*/
}
#login_support {
	/*Background Images moved to login.php for subdirectory installs*/
}
.login_item_title {
	display: inline-block;
	width: 150px;
	margin: auto 20px;
}
#login_icon_holder {
	width: 80%;
	margin: auto;
	position: relative; /*absolute;*/
	margin-top:10%;
	left: 0;
	right: 0;
	height: 70%;
	bottom: 0;
	text-align:center;
	overflow: hidden;
}
#login_form {
	display: none;
}
.obe_error {
	color: red;
	font-weight: bold;
}
/***** right nav's ********/
.rnav {
	float:right;
	position: relative;
	margin-top:10px;
	right: 1.5%;
}
.rnav ul {
	/* make it scroll */
	max-height:50em;
	max-width:275px;
	overflow:auto;
}

/* Smaller sizes use a smaller em on the rnav ul */
@media all and (max-height: 700px) {
	.rnav ul {
		max-height:25em;
	}
}

/*** reload button ****/
#button_reload {
	display:none;
}
/**** global elements ****/
a {
	text-decoration:none;
	color:#2779AA;
}
a:visited {
	color:#072966;
}
a:hover {
	color:#ff9933;
}
h1, h2, h3, h4, h5, h6 {
	color: gray;
}
input, textarea {
	border:1px solid #ccc;
}
input[type=text]:hover:not([disabled]) {border-color: #666 #CCC #CCC #CCC;}
hr {
	background-color: #DEEDF7;
	border: 1px solid #AED0EA;
	height: 3px;
	border-radius: 5px;
}
input[type=email]:invalid {
	border: 2px solid red;
}
.duplicate-exten {
	border: 2px solid red;
}
.attention {
	background:#ff9933;
	/*background:red;*/
	color:white;
	font-weight:bold;
}
.attention a {
	color:white;
	font-weight:bold;
}
.attention img {
	vertical-align:top;
	padding-right:5px;
}
div.attention {
	border:1px solid black;
	padding:5px;
}
.warning {
	padding:10px 10px 0 10px;
	margin:5px 0;
	background:rgb(255,242,202);
	border:1px dotted #ccc;
}
.warning p {
	margin-top: 0;
	margin-bottom:10px;
}

#login_message {
	position:absolute;
	top:55px;
	right:5px;
	width: 180px;
	font-size:12px;
	background-color: transparent;
}
#login_message a:link {
	background-color: transparent;
}
#message-old {
	position:absolute;
	top:85px;
	right:15px;
	font-size:12px;
}

/************************* For modules page *************************/
#shield_link_div {
	float:right;
}
#shield_link {
	background-size: 96px 138px;
	display:inline-block;
	height:138px;
	width:96px;
	margin:8px;
	position:relative;
	top:-50px;
}
#shield_link.updates_off {
	background-image: url(../../assets/images/modules/Notify-upgrade-badge-red.png);
}
#shield_link.updates_partial {
	background-image: url(../../assets/images/modules/Notify-upgrade-badge-yellow.png);
}
#shield_link.updates_full {
	background-image: url(../../assets/images/modules/Notify-upgrade-badge-green.png);
}
#modulelist ul {
	padding-left:0;
	margin-left:0;
	position:relative;
}
#modulelist li {
    list-style-type: none;
	border:1px solid #808080;
}
#modulelist #modulelist-header {
	position:relative;
}
#modulelist #modulelist-header span {
	font-size:12px;
	font-weight:bold;
}
#modulelist .moduleheader {
	background:#ccc;
	padding:2px;
}
#modulelist .modulevulnerable {
	background:#f6921d;
	padding:2px;
}
#modulelist .modulename {
	position:absolute;
	left:2px;
}
#modulelist .moduleversion {
	position:absolute;
	left: 230px;
}
#modulelist .modulepublisher {
	position:absolute;
	left: 350px;
}
#modulelist .modulestatus {
	position:absolute;
	left: 560px;
  overflow: hidden;
}
#modulelist .modulevul {
	position:absolute;
	left: 850px;
  overflow: hidden;
}
#modulelist .clear {
	clear:both;
}
div.modulebuttons {
	margin:0.5em 0 0.5em 0;
	text-align:right;
	width:100%;
}
#moduleprogress .error {
	color:red;
	font-weight:bold;
}
#moduleprogress .success {
	color:#e5edd5;
	font-weight:bold;
}
#moduleprogress hr {
	margin-left:0;
	width:40%;
	color:#ccc;
}

/* for the tabber --modue-admin--*/
#modulelist .tabber, #modulelist .tabberlive {
}
#modulelist div.moduleinfopane {
	display:none; /* hide the information pane by default */
	background: #eee;
	height:7em; /* div.tabbertab height should be .5 less than this */
}
#modulelist ul.tabbernav {
	width:8em;
	float:left;
	margin-left:0em;
}
#modulelist ul.tabbernav li {
	text-align:right;
	padding:2px 7px 2px 2px;
    border-right: 5px solid #808080;
    border-left: 1px solid #ccc;
    border-bottom: 1px solid #ccc;
}
#modulelist ul.tabbernav li.tabberactive a {
	color: #f68a00;
	font-weight:bold;
}
#modulelist ul.tabbernav li a {
	text-decoration : none;
}
#modulelist div.tabbertab {
	margin-left:1.5em;
	height:6.5em; /* This should be .5 less than div.moduleinfopain height */
	overflow:auto;
}
#modulelist h5 {
	margin-top: 0;
	margin-bottom: 0.5em;
}
#modulelist .alert {
	color:#a00;
}
#modulelist .notinstalled {
	color:#2B77FE;
}
#modulelist div.moduleinfopane .actiontab {
	padding-left:10px;
}

/************************* For tabber *************************/
/*--------------------------------------------------
  REQUIRED to hide the non-active tab content.
  But do not hide them in the print stylesheet!
  --------------------------------------------------*/
.tabberlive .tabbertabhide {
 display:none;
}


/**** tables with alternating colors ***/
.alt_table tr:nth-child(even){background-color: #DEEDF7;}

/*****gui eleements show/hide section ****/
.guielToggleBut {
	cursor: pointer;
}
/************** jQuery UI *************************/
.ui-widget{font-size:11px !important;}/*text size AND layout size of ui eleements*/
.ui-sortable li{cursor:move}/* sortables and others*/

/*top menu bar*/
.menubar{height: 29px;}

#MENU_BRAND_IMAGE_TANGO_LEFT{min-width: 40px;}
.menubar > a + ul{display: none;}/*dropdown menus should be intially hidden*/
.menubar > a {margin: 2px 1px; height: 23px;}/*spacing around menubar buttons*/
.menubar { padding-left: 3px;}/*spacing beteen firsl/last button and toolbar edge*/
.menubar .ui-menu {position: absolute; outline: none; z-index: 9999; overflow-y: auto;}/*actual toolbar layout*/
.menubar .ui-menu .ui-icon { float: right; }/*button icons*/
.menubar .button-right{float: right; right: 4px;}/*right side buttons*/
.menubar .ui-menu li.ui-state-disabled {/*disabled menue items*/
	font-weight: bold;
	padding: .0em .4em;
	margin: .4em 0 .2em;
	line-height: 1.5;
}
/*not sure what this does -MB*/
.menubar .ui-menu  a {
	color: #2E6E9E;
	font-weight: normal;
}

/*submit button size*/
input[type="submit"]{ height: 25px;}

/*rnav*/
.rnav .ui-widget-content {background: none;}
.rnav .ui-widget-content a {color: #072966;}

/* menubar logo */
#MENU_BRAND_IMAGE_TANGO_LEFT {
	height:23px;
	margin:4px;
	cursor:pointer;
	float:left;
}

/*ajax spinner*/
#ajax_spinner {
	display: none;
	width: 28px;
	margin: 4px;
	margin-top: 7px;
	transform: rotate(90deg);
	-webkit-transform: rotate(90deg);
	-moz-transform: rotate(90deg);
	filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
}
