/* 
 * Header
 */

/* Header */

#ariHeader {
  position: relative;
  background: #BEC8D1;
  height: 55px;
  margin: 0;
  padding: 0;
  clear: both;
}

#ariHeader span.left {
  position: relative;
  height: 55px;
  border: 0px;
  padding: 0px;
  margin: 0px;
  float: left;
}

#ariHeader img { 
  border: 0px; 
  margin-left:2px;
}

#ariHeader span.right {
  height: 55px;
  border: 0px;
  padding: 0px;
  margin: 0px;
  float: right;
}

#ariHeader img {
  border: 0px;
}

/* Topnav */

#topnav {
  width: 100%;
  height: 36px;
  border: 0;
  padding: 0;
  margin-top: -1px;  /* stupid browser hack */
  color: #999;
  background-color: #333;
}

#topnav span.left {
  float: left;
  text-align: left;
  font-weight: bold;
  color: #fff;
  width: 49%;
}

#topnav span.right {
  float: right;
  text-align: right;
  font-weight: bold;
  color: #fff;
  width: 49%;
}

.topnav small b  {
  font-family: Verdana, Helvetica, Arial, sans-serif;
  font-weight: bold;
  background-color: #105D90;
}

/* Headerspacer */

#headerspacer {
  border: 0; 
  padding: 0;
  margin-top: -16px;  /* stupid browser hack */
  background-color: #fff;
  height: 16px
}
