/*
 * Navigation
 */

/* Menu */

#menu {
  width: 148px;
  float: left;
}

/* Nav */

.nav {
  font-weight: bold;
  color: #105D90;
  margin-right: 20px;
}

.nav p {
  margin:  0px;
  padding-top: 2px;
  padding-bottom: 3px;
  background: #FFF; 
}

.nav a:visited  {
  color: #105D90;
}

.sub    {
  margin-left: 1em;
}

.navtext {
  margin-left: 20px;
}

.nav_b1 {
  height: 1px; 
  font-size: 1px; 
  overflow: hidden; 
  display: block; 
  background: #EEE; 
  margin:0 5px;
}

.nav_b2 {
  height: 1px; 
  font-size: 1px; 
  overflow: hidden; 
  display: block; 
  background: #FFF; 
  border-right: 2px solid #EEE; 
  border-left: 2px solid #EEE; 
  margin:0 3px;
}

.nav_b3 {
  height: 1px; 
  font-size: 1px; 
  overflow: hidden; 
  display:block; 
  background: #FFF; 
  border-right: 1px solid #EEE; 
  border-left: 1px solid #EEE; 
  margin: 0 2px;
}

.nav_b4 {
  height: 2px; 
  font-size: 1px; 
  overflow: hidden; 
  display:block; 
  background: #FFF;
  border-right: 1px solid #EEE; 
  border-left:1px solid #EEE; 
  margin:0 1px;
}

#nav_menu {
  background: #FFF; 
  border-right: 1px solid #EEE; 
  border-left: 1px solid #EEE;
  padding-left: 0.75em;
}

/* Subnav */

.subnav {
  font-weight: bold;
  color: #105D90;
  margin-right: 20px;
}

.subnav p {
  margin:  0px;
  padding-top: 2px;
  padding-bottom: 3px;
  background: #BEC8D1; 
}

.subnav a:visited  {
  color: #105D90;
}

.subnav a.current, a:visited.current {
  color: #404040;
}

.subnav_b1 {
  height: 1px; 
  font-size: 1px; 
  overflow: hidden; 
  display: block; 
  background: #aaa; 
  margin:0 5px;
}

.subnav_b2 {
  height: 1px; 
  font-size: 1px; 
  overflow: hidden; 
  display: block; 
  background: #BEC8D1; 
  border-right: 2px solid #aaa; 
  border-left: 2px solid #aaa; 
  margin:0 3px;
}

.subnav_b3 {
  height: 1px; 
  font-size: 1px; 
  overflow: hidden; 
  display:block; 
  background: #BEC8D1; 
  border-right: 1px solid #aaa; 
  border-left: 1px solid #aaa; 
  margin: 0 2px;
}

.subnav_b4 {
  height: 2px; 
  font-size: 1px; 
  overflow: hidden; 
  display:block; 
  background: #BEC8D1;
  border-right: 1px solid #aaa; 
  border-left:1px solid #aaa; 
  margin:0 1px;
}

.subnav_title {
  font-weight: normal;
  color: #105D90;
  font-size: 12px;
  padding-left: 1em;
}

#subnav_menu {
  background: #BEC8D1; 
  border-right: 1px solid #aaa; 
  border-left: 1px solid #aaa;
  padding-left: 1.25em;
}

