/*
 * Layout 
 */

/* Page */

#page {
  background-color: white;
  text-align: left;
  min-width: 760px;
}

/* main */

#main {
  min-width: 760px;
  float: left;
}

#main span.left {
  float: left;
}

#main span.right {
  float: left;
}

/* Center */

#center {
  float: left;
  margin-bottom: 20px;
}

/* Login */

#login  {  
  margin: 0;
  padding: 0;
}
#login p { 
  font-size: 0.7em;
}
table#login  {  
  width: 600px;
  border: 0px;
}
table#login td.right {  
  text-align: right;
  width: 20%;
}
table#login td.left {  
  text-align: left;
}
table#login td.small {  
  font-size: 0.7em;
}
table#login_text  { 
  margin-left: 60px; 
  font-size: 0.8em;
  text-align: left;
}

/* i18n lang */

.lang {
  display: inline;
  font-size: 0.8em;
  margin: 0;
  padding: 0;
}
.lang_code {
  margin: 0;
  padding: 0;
  width: 10em;
}

/* Line */

#line {
  min-width: 604px;
  border: 1px solid #333; 
  padding: 0;
  margin: 0;  
  color: #999;
  background-color: #333;
  height: 1px;
}
#line span.left {
  float: left;
  text-align: left;
  font-weight: bold;
  color: #fff;
  width: 49%;
}
#line span.right {
  float: right;
  text-align: right;
  font-weight: bold;
  color: #fff;
  width: 49%;
}

/* Navbar */

#navbar {
  width: 604px;
  height: 24px;
  border: 1px; 
  padding: 0;
  margin-bottom: 0;
  color: #fff;
  background-color: #333;
}
#navbar span.left {
  margin: 2px;
  float: left;
  text-align: left;
  font-weight: bold;
  vertical-align: middle;
  width: 49%;
}
#navbar span.right {
  margin: 2px;
  float: right;
  text-align: right;
  font-weight: bold;
  vertical-align: middle;
  width: 49%;
}

/* Info Bar */

#info_bar {
  min-width: 604px;
  border: 1px solid #333; 
  padding: 3px;
  margin-top: -1px;  /* stupid browser hack */
  color: #999;
  background-color: #333;
  height: 20px;
}
#info_bar span.left {
  float: left;
  text-align: left;
  font-weight: bold;
  color: #fff;
  width: 49%;
}
#info_bar span.right {
  float: right;
  text-align: right;
  font-weight: bold;
  color: #fff;
  width: 49%;
}
.info_bar a:link {
  color: white;
  text-decoration: none;
}
.info_bar a:active, a:link {
  color: #105D90;
}
.info_bar a:hover {
  color: #fc0;
}
.info_bar small b  {
  font-family: Verdana, Helvetica, Arial, sans-serif;
  font-weight: bold;
}
input.infoBar {
  font-size: 11px;
  padding: 0px;
  height: 22px;
}

/* bars */

.bar {
  margin: 0;
}

.bar_left {
  width: 604px;
  margin: 0 0 16px 0; 
  padding: 0;
}

.bar_center {
  width: 604px;
  text-align: center;
  margin: 0 0 16px 0; 
  padding: 0;
}
.bar_center a:active, .bar_center a:hover {
  color: red;
}

/* Subheader */

#subheader {
  padding: 0px; 
  margin: 0px;
  margin-bottom: 16px;
}

/* servBodL */

.servBodL { 
  border-left: 1px dotted #CEDCEA; 
}

/* Callmonitor */

table.callmonitor { 
  border: 1px #6699CC solid;
  border-collapse: collapse;
  border-spacing: 0px;
  margin: 0 0 16px 0;
  width: 604px;
}
table.callmonitor th { 
  background-color: #BEC8D1;
  border: 1px solid #6699CC;
  border-bottom: 2px solid #6699CC;
  text-align: center;
  font-family: Verdana;
  font-weight: bold;
  font-size: 0.7em;
  color: #404040;
}
table.callmonitor th a { 
  color: #404040;
}
table.callmonitor img { 
  border: 0;
}
table.callmonitor td { 
  background-color: white;
  border: 1px solid #6699CC;
  color: #404040;
  font-family: Verdana, sans-serif, Arial;
  font-weight: normal;
  font-size: 0.7em;
  padding: 3px;
  text-align: center;
}
table.callmonitor td.checkbox { 
  padding: 1px;
}

/* Voicemail */

.voicemail {
  margin: 0px;
}
table.voicemail { 
  border: 1px #6699CC solid;
  border-collapse: collapse;
  border-spacing: 0px;
  margin: 0 0 16px 0;
  width: 604px;
}
table.voicemail th { 
  background-color: #BEC8D1;
  border: 1px solid #6699CC;
  border-bottom: 2px solid #6699CC;
  text-align: center;
  font-family: Verdana;
  font-weight: bold;
  font-size: 0.7em;
  color: #404040;
}
table.voicemail th a { 
  color: #404040;
}
table.voicemail img { 
  border: 0;
}
table.voicemail td { 
  background-color: white;
  border: 1px solid #6699CC;
  color: #404040;
  font-family: Verdana, sans-serif, Arial;
  font-weight: normal;
  font-size: 0.7em;
  padding: 3px;
  text-align: center;
}
table.voicemail td.checkbox { 
  padding: 1px;
}

/* Help */

.fcHelp {
  margin: 0px;
}
table.fcHelp { 
  border: 1px #6699CC solid;
  border-collapse: collapse;
  border-spacing: 0px;
  margin: 0 0 16px 0;
}
table.fcHelp th { 
  background-color: #BEC8D1;
  border: 1px solid #6699CC;
  border-bottom: 2px solid #6699CC;
  font-family: Verdana;
  font-weight: bold;
  font-size: 0.7em;
  color: #404040;
}
table.fcHelp th.feature_codes { 
  text-align: center;
  width: 9em;
}
table.fcHelp th a { 
  color: #404040;
}
table.fcHelp img { 
  border: 0;
}
table.fcHelp td { 
  background-color: white;
  border: 1px solid #6699CC;
  color: #404040;
  font-family: Verdana, sans-serif, Arial;
  font-weight: normal;
  font-size: 0.7em;
  padding: 3px;
}
table.fcHelp td.feature_codes { 
  text-align: center;
}
table.fcHelp td.checkbox { 
  padding: 1px;
}

/* Settings */

.settings { 
  font-family: Verdana, sans-serif, Arial;
  font-weight: normal;
  font-size: 0.9em;
  padding: 0;
  margin: 0;
}
table.settings { 
  font-family: Verdana;
  color: #404040;
  border-collapse: collapse;
  border-spacing: 0px;
  padding-bottom: 3px;
}
table.settings td { 
  color: #404040;
  background-color: white;
  padding: 3px;
}
table.settings td.note { 
  color: #105D90;
}

/* Footer */

#ariFooter {
  color: #999;
  margin-left: 148px;
  font-size: 10px;
  overflow: auto;
/*  width: 100%; */
  clear: both;
}

#ariFooter a {
  text-decoration: none;
  color: #999;
  /* margin-left:2px; */
}

#ariFooter a:hover {
  text-decoration: underline;  
  color: #105D90;
}

#ariFooter a:link {
  text-decoration: none;
  color: #999;
}

/* Misc */

.ariClearBoth {
  clear: both;
  margin: 0;
  padding: 0;
}

.ariBlockHide {
  display: none;
  height: 0;
  width: 0;
  overflow: hidden;
  position: absolute;  /* IE5 Mac */
}















